==> apache-camel-3.8.0-src.zip: apache-camel-3.8.0/test-infra/camel-test-infra-fhir/src/test/java/org/apache/camel/test/infra/fhir/services/FhirServiceFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.infra.fhir.services;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public final class FhirServiceFactory {
    private static final Logger LOG = LoggerFactory.getLogger(FhirServiceFactory.class);

    private FhirServiceFactory() {

    }

    public static FhirService createService() {
        String instanceType = System.getProperty("fhir.instance.type");

        if (instanceType == null || instanceType.equals("local-fhir-container")) {
            return new FhirLocalContainerService();
        }

        if (instanceType.equals("remote")) {
            return new FhirRemoteService();
        }

        LOG.error("FHIR instance must be one of 'local-fhir-container' or 'remote");
        throw new UnsupportedOperationException("Invalid FHIR instance type");
    }
}

==> apache-camel-4.8.9-src.zip: apache-camel-4.8.9/test-infra/camel-test-infra-fhir/src/test/java/org/apache/camel/test/infra/fhir/services/FhirServiceFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.infra.fhir.services;

import org.apache.camel.test.infra.common.services.SimpleTestServiceBuilder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public final class FhirServiceFactory {
    private static final Logger LOG = LoggerFactory.getLogger(FhirServiceFactory.class);

    private FhirServiceFactory() {

    }

    public static SimpleTestServiceBuilder<FhirService> builder() {
        return new SimpleTestServiceBuilder<>("fhir");
    }

    public static FhirService createService() {
        return builder()
                .addLocalMapping(FhirLocalContainerService::new)
                .addRemoteMapping(FhirRemoteService::new)
                .build();
    }

    public static FhirService createSingletonService() {
        return builder()
                .addLocalMapping(() -> new FhirLocalSingletonContainerService())
                .addRemoteMapping(FhirRemoteService::new)
                .build();
    }
}
